| HDOMdesign | R Documentation |
Generates a high-dimensional orthogonal maximin distance designs.
HDOMdesign(n,p,s)
HDOM2(n,p)
HDOM4(n,p)
HDOM8(n,p)
HDOM16(n,p)
n |
Number of points. |
p |
Number of dimensions. |
s |
Number of levels. |
These functions generate high-dimensional orthogonal maximin distance designs. In particular, HDOM2, HDOM4, HDOM8, and HDOM16 generate designs in two, four, eight, and sixteen levels.
The value returned from the function is an n times p matrix giving the experimental design
HDOM2(n=80,p=60)
HDOM4(n=80,p=60)
HDOM8(n=80,p=60)
HDOM16(n=80,p=60)
HDOMdesign(n=80,p=60,s=4)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.